@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::Compile;
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.003'; # TRIAL
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.004'; # TRIAL
 }
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -64,7 +64,7 @@ CODE
     my $fail_on_warning = $self->fail_on_warning ne 'none'
         ? q{is(scalar(@warnings), 0, 'no warnings found');}
         : '';
-    $fail_on_warning = 'if ($ENV{AUTHOR_TESTING} { ' . $fail_on_warning . ' }'
+    $fail_on_warning = 'if ($ENV{AUTHOR_TESTING}) { ' . $fail_on_warning . ' }'
         if $self->fail_on_warning eq 'author';
 
     my $test_more_version = $self->bail_out_on_fail ? ' 0.94' : ' 0.88';
@@ -101,7 +101,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.003
+version 2.004
 
 =head1 SYNOPSIS
 
